require 'erb'

class Driftwood::Plugin::Onboard < Driftwood::Plugin

  def initialize(config=nil, slack=nil, bigquery=nil)
    super(config, slack, bigquery)
    @about = 'Provides onboarding services for new users.'

    @slack.register_handler('team_join') do |team_id, event_data|
      user = @slack.normalize_user(event_data['user'])
      $logger.info "User #{user['name']} (#{user['real_name']}) joined the workspace"

      filename = File.expand_path(config[:workspace]) rescue nil
      if filename
        begin
          $logger.debug "Sending team welcome from #{filename}"
          template = ERB.new(File.read(filename))
          @slack.send_response(team_id, event_data['user'], template.result(binding))
        rescue => e
          $logger.info "Sending onboarding welcome failed: #{e.message}"
          $logger.debug e.backtrace.join("\n")
        end
      end
    end

    @slack.register_handler('member_joined_channel') do |team_id, event_data|
      user    = @slack.user_info(event_data['team'], event_data['user'])
      user    = @slack.normalize_user(user)
      channel = @slack.channel_name(event_data['team'], event_data['channel'])
      $logger.info "User #{user['name']} (#{user['real_name']}) joined ##{channel}"

      filename = File.expand_path(config[:channels][channel]) rescue nil
      if filename
        begin
          $logger.debug "Sending channel welcome from #{filename}"
          template = ERB.new(File.read(filename))
          @slack.send_response(team_id, event_data['user'], template.result(binding))
        rescue => e
          $logger.info "Sending channel welcome failed: #{e.message}"
          $logger.debug e.backtrace.join("\n")
        end
      end
    end

  end
end